Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type DestinationRuleExpansion
- type DestinationRuleInterface
- type DestinationRulesGetter
- type EnvoyFilterExpansion
- type EnvoyFilterInterface
- type EnvoyFiltersGetter
- type GatewayExpansion
- type GatewayInterface
- type GatewaysGetter
- type NetworkingV1alpha3Client
- func (c *NetworkingV1alpha3Client) DestinationRules(namespace string) DestinationRuleInterface
- func (c *NetworkingV1alpha3Client) EnvoyFilters(namespace string) EnvoyFilterInterface
- func (c *NetworkingV1alpha3Client) Gateways(namespace string) GatewayInterface
- func (c *NetworkingV1alpha3Client) RESTClient() rest.Interface
- func (c *NetworkingV1alpha3Client) ServiceEntries(namespace string) ServiceEntryInterface
- func (c *NetworkingV1alpha3Client) Sidecars(namespace string) SidecarInterface
- func (c *NetworkingV1alpha3Client) VirtualServices(namespace string) VirtualServiceInterface
- type NetworkingV1alpha3Interface
- type ServiceEntriesGetter
- type ServiceEntryExpansion
- type ServiceEntryInterface
- type SidecarExpansion
- type SidecarInterface
- type SidecarsGetter
- type VirtualServiceExpansion
- type VirtualServiceInterface
- type VirtualServicesGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DestinationRuleExpansion ¶
type DestinationRuleExpansion interface{}
type DestinationRuleInterface ¶
type DestinationRuleInterface interface {
Create(*v1alpha3.DestinationRule) (*v1alpha3.DestinationRule, error)
Update(*v1alpha3.DestinationRule) (*v1alpha3.DestinationRule, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha3.DestinationRule, error)
List(opts v1.ListOptions) (*v1alpha3.DestinationRuleList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha3.DestinationRule, err error)
DestinationRuleExpansion
}
DestinationRuleInterface has methods to work with DestinationRule resources.
type DestinationRulesGetter ¶
type DestinationRulesGetter interface {
DestinationRules(namespace string) DestinationRuleInterface
}
DestinationRulesGetter has a method to return a DestinationRuleInterface. A group's client should implement this interface.
type EnvoyFilterExpansion ¶
type EnvoyFilterExpansion interface{}
type EnvoyFilterInterface ¶
type EnvoyFilterInterface interface {
Create(*v1alpha3.EnvoyFilter) (*v1alpha3.EnvoyFilter, error)
Update(*v1alpha3.EnvoyFilter) (*v1alpha3.EnvoyFilter, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha3.EnvoyFilter, error)
List(opts v1.ListOptions) (*v1alpha3.EnvoyFilterList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha3.EnvoyFilter, err error)
EnvoyFilterExpansion
}
EnvoyFilterInterface has methods to work with EnvoyFilter resources.
type EnvoyFiltersGetter ¶
type EnvoyFiltersGetter interface {
EnvoyFilters(namespace string) EnvoyFilterInterface
}
EnvoyFiltersGetter has a method to return a EnvoyFilterInterface. A group's client should implement this interface.
type GatewayExpansion ¶
type GatewayExpansion interface{}
type GatewayInterface ¶
type GatewayInterface interface {
Create(*v1alpha3.Gateway) (*v1alpha3.Gateway, error)
Update(*v1alpha3.Gateway) (*v1alpha3.Gateway, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha3.Gateway, error)
List(opts v1.ListOptions) (*v1alpha3.GatewayList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha3.Gateway, err error)
GatewayExpansion
}
GatewayInterface has methods to work with Gateway resources.
type GatewaysGetter ¶
type GatewaysGetter interface {
Gateways(namespace string) GatewayInterface
}
GatewaysGetter has a method to return a GatewayInterface. A group's client should implement this interface.
type NetworkingV1alpha3Client ¶
type NetworkingV1alpha3Client struct {
// contains filtered or unexported fields
}
NetworkingV1alpha3Client is used to interact with features provided by the networking.istio.io group.
func New ¶
func New(c rest.Interface) *NetworkingV1alpha3Client
New creates a new NetworkingV1alpha3Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*NetworkingV1alpha3Client, error)
NewForConfig creates a new NetworkingV1alpha3Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *NetworkingV1alpha3Client
NewForConfigOrDie creates a new NetworkingV1alpha3Client for the given config and panics if there is an error in the config.
func (*NetworkingV1alpha3Client) DestinationRules ¶
func (c *NetworkingV1alpha3Client) DestinationRules(namespace string) DestinationRuleInterface
func (*NetworkingV1alpha3Client) EnvoyFilters ¶
func (c *NetworkingV1alpha3Client) EnvoyFilters(namespace string) EnvoyFilterInterface
func (*NetworkingV1alpha3Client) Gateways ¶
func (c *NetworkingV1alpha3Client) Gateways(namespace string) GatewayInterface
func (*NetworkingV1alpha3Client) RESTClient ¶
func (c *NetworkingV1alpha3Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*NetworkingV1alpha3Client) ServiceEntries ¶
func (c *NetworkingV1alpha3Client) ServiceEntries(namespace string) ServiceEntryInterface
func (*NetworkingV1alpha3Client) Sidecars ¶
func (c *NetworkingV1alpha3Client) Sidecars(namespace string) SidecarInterface
func (*NetworkingV1alpha3Client) VirtualServices ¶
func (c *NetworkingV1alpha3Client) VirtualServices(namespace string) VirtualServiceInterface
type NetworkingV1alpha3Interface ¶
type NetworkingV1alpha3Interface interface {
RESTClient() rest.Interface
DestinationRulesGetter
EnvoyFiltersGetter
GatewaysGetter
ServiceEntriesGetter
SidecarsGetter
VirtualServicesGetter
}
type ServiceEntriesGetter ¶
type ServiceEntriesGetter interface {
ServiceEntries(namespace string) ServiceEntryInterface
}
ServiceEntriesGetter has a method to return a ServiceEntryInterface. A group's client should implement this interface.
type ServiceEntryExpansion ¶
type ServiceEntryExpansion interface{}
type ServiceEntryInterface ¶
type ServiceEntryInterface interface {
Create(*v1alpha3.ServiceEntry) (*v1alpha3.ServiceEntry, error)
Update(*v1alpha3.ServiceEntry) (*v1alpha3.ServiceEntry, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha3.ServiceEntry, error)
List(opts v1.ListOptions) (*v1alpha3.ServiceEntryList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha3.ServiceEntry, err error)
ServiceEntryExpansion
}
ServiceEntryInterface has methods to work with ServiceEntry resources.
type SidecarExpansion ¶
type SidecarExpansion interface{}
type SidecarInterface ¶
type SidecarInterface interface {
Create(*v1alpha3.Sidecar) (*v1alpha3.Sidecar, error)
Update(*v1alpha3.Sidecar) (*v1alpha3.Sidecar, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha3.Sidecar, error)
List(opts v1.ListOptions) (*v1alpha3.SidecarList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha3.Sidecar, err error)
SidecarExpansion
}
SidecarInterface has methods to work with Sidecar resources.
type SidecarsGetter ¶
type SidecarsGetter interface {
Sidecars(namespace string) SidecarInterface
}
SidecarsGetter has a method to return a SidecarInterface. A group's client should implement this interface.
type VirtualServiceExpansion ¶
type VirtualServiceExpansion interface{}
type VirtualServiceInterface ¶
type VirtualServiceInterface interface {
Create(*v1alpha3.VirtualService) (*v1alpha3.VirtualService, error)
Update(*v1alpha3.VirtualService) (*v1alpha3.VirtualService, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha3.VirtualService, error)
List(opts v1.ListOptions) (*v1alpha3.VirtualServiceList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha3.VirtualService, err error)
VirtualServiceExpansion
}
VirtualServiceInterface has methods to work with VirtualService resources.
type VirtualServicesGetter ¶
type VirtualServicesGetter interface {
VirtualServices(namespace string) VirtualServiceInterface
}
VirtualServicesGetter has a method to return a VirtualServiceInterface. A group's client should implement this interface.